==> fw_storage-2.1.7-py3-none-any.whl: fw_storage/fileinfo.py <==
"""File-info module."""
import dataclasses
import typing as t
from pathlib import Path


@dataclasses.dataclass(frozen=True)
class FileInfo:
    """FileInfo dataclass yielded from storage.ls() calls.

    Path is unique and relative to the storage prefix. Slots minimize memory
    usage to allow storing large number of FileInfo instances at once.
    """

    __slots__ = ("path", "size", "hash", "created", "modified")

    path: str
    size: int
    hash: t.Optional[str]
    created: t.Optional[t.Union[int, float]]
    modified: t.Optional[t.Union[int, float]]

    def asdict(self) -> t.Dict:
        """Return as a dictionary."""
        # TODO performance-test this and improve as needed
        return dataclasses.asdict(self)  # pragma: no cover

    def dict(self) -> t.Dict:  # pragma: no cover
        """Future compatibility."""
        return self.asdict()

    @property
    def dir(self) -> str:  # pragma: no cover
        """Return the directory name of this path."""
        dirname = str(Path(self.path).parent)
        return "" if dirname == "." else dirname

    @property
    def name(self) -> str:  # pragma: no cover
        """Return the base filename of this path."""
        return Path(self.path).name

    @property
    def stem(self) -> str:  # pragma: no cover
        """Return the filename stem without any extension suffix."""
        return Path(self.path).stem

    @property
    def ext(self) -> str:  # pragma: no cover
        """Return the extension of this path."""
        return Path(self.path).suffix.lstrip(".")

    def __str__(self) -> str:  # pragma: no cover
        """Return the path string."""
        return self.path

==> fw_storage-2.1.10-py3-none-any.whl: fw_storage/fileinfo.py <==
"""File-info module."""
import dataclasses
import typing as t
from pathlib import Path


@dataclasses.dataclass(frozen=True)
class FileInfo:
    """FileInfo dataclass yielded from storage.ls() calls.

    Path is unique and relative to the storage prefix. Slots minimize memory
    usage to allow storing large number of FileInfo instances at once.
    """

    __slots__ = ("type", "path", "size", "hash", "created", "modified")

    type: t.Literal["fs", "s3", "gs", "az", "dicom"]
    path: str
    size: int
    hash: t.Optional[str]
    created: t.Optional[t.Union[int, float]]
    modified: t.Optional[t.Union[int, float]]

    def asdict(self) -> t.Dict:
        """Return as a dictionary."""
        # TODO performance-test this and improve as needed
        return dataclasses.asdict(self)  # pragma: no cover

    def dict(self) -> t.Dict:  # pragma: no cover
        """Future compatibility."""
        return self.asdict()

    @property
    def dir(self) -> str:  # pragma: no cover
        """Return the directory name of this path."""
        dirname = str(Path(self.path).parent)
        return "" if dirname == "." else dirname

    @property
    def name(self) -> str:  # pragma: no cover
        """Return the base filename of this path."""
        return Path(self.path).name

    @property
    def stem(self) -> str:  # pragma: no cover
        """Return the filename stem without any extension suffix."""
        return Path(self.path).stem

    @property
    def ext(self) -> str:  # pragma: no cover
        """Return the extension of this path."""
        return Path(self.path).suffix.lstrip(".")

    def __str__(self) -> str:  # pragma: no cover
        """Return the path string."""
        return self.path
